==> apache-qpid-broker-j-9.0.0-src.tar.gz: apache-qpid-broker-j-9.0.0-src/broker-core/src/main/java/org/apache/qpid/server/model/preferences/UserPreferences.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.qpid.server.model.preferences;

import java.util.Collection;
import java.util.Set;
import java.util.UUID;

import com.google.common.util.concurrent.ListenableFuture;

public interface UserPreferences
{
    ListenableFuture<Void> updateOrAppend(Collection<Preference> preferences);

    ListenableFuture<Set<Preference>> getPreferences();

    ListenableFuture<Void> replace(Collection<Preference> preferences);

    ListenableFuture<Void> replaceByType(String type, Collection<Preference> preferences);

    ListenableFuture<Void> replaceByTypeAndName(String type, String name, Preference preference);

    ListenableFuture<Set<Preference>> getVisiblePreferences();

    ListenableFuture<Void> delete(String type, String name, UUID id);
}

==> apache-qpid-broker-j-10.0.0-src.tar.gz: apache-qpid-broker-j-10.0.0-src/broker-core/src/main/java/org/apache/qpid/server/model/preferences/UserPreferences.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.qpid.server.model.preferences;

import java.util.Collection;
import java.util.Set;
import java.util.UUID;
import java.util.concurrent.CompletableFuture;

public interface UserPreferences
{
    CompletableFuture<Void> updateOrAppend(Collection<Preference> preferences);

    CompletableFuture<Set<Preference>> getPreferences();

    CompletableFuture<Void> replace(Collection<Preference> preferences);

    CompletableFuture<Void> replaceByType(String type, Collection<Preference> preferences);

    CompletableFuture<Void> replaceByTypeAndName(String type, String name, Preference preference);

    CompletableFuture<Set<Preference>> getVisiblePreferences();

    CompletableFuture<Void> delete(String type, String name, UUID id);
}
